@@ -118,7 +118,8 @@ class ChangeEntry(Entry):
             m = _fileRegex.search(line)
             if m:
                 fileName = m.expand("\\1")
-                self.files.append(fileName)
+                if fileName not in self.files:
+                    self.files.append(fileName)
             m = _byRegex.search(line)
             if m:
                 # only append entries that we actually have a name for
@@ -203,11 +204,18 @@ class ChangeLogFile(log.Loggable):
         @type  allEntries: bool
         """
         def parseBlock(block):
+            if not block:
+                raise TypeError(
+                    "ChangeLog entry is empty")
             self._blocks.append(block)
             if _nameRegex.match(block[0]):
                 entry = ChangeEntry()
             elif _releaseRegex.match(block[0]):
                 entry = ReleaseEntry()
+            else:
+                raise TypeError(
+                    "ChangeLog entry doesn't match any known types:\n%s" % 
+                        block)
 
             # FIXME: shouldn't the base class handle this, then delegate ?
             entry.lines = block
@@ -279,7 +287,7 @@ class ChangeLogFile(log.Loggable):
         return res
 
 class Checkin(util.LogCommand):
-    usage = "checkin [path to directory or ChangeLog file]"
+    usage = "[path to directory or ChangeLog file]"
     summary = "check in files listed in the latest ChangeLog entry"
     description = """Check in the files listed in the latest ChangeLog entry.
 
@@ -314,7 +322,7 @@ Supported VCS systems: %s""" % ", ".join(vcs.getNames())
             self.stderr.write(
                 'ChangeLog entry has not been updated properly:')
             self.stderr.write("\n - ".join(['', ] + entry.notEdited) + "\n")
-            self.stderr.write("Please fix the entry and try again.")
+            self.stderr.write("Please fix the entry and try again.\n")
             return 3
         self.debug('Commiting files %r' % entry.files)
         ret = v.commit([clName, ] + entry.files, entry.text)
@@ -324,7 +332,7 @@ Supported VCS systems: %s""" % ", ".join(vcs.getNames())
         return 0
 
 class Contributors(util.LogCommand):
-    usage = "contributors [path to directory or ChangeLog file]"
+    usage = "[path to directory or ChangeLog file]"
     summary = "get a list of contributors since the previous release"
     aliases = ["cont", "contrib"]
 
@@ -475,7 +483,7 @@ to the ChangeLog file as an argument, so you can alias
 'moap changelog checkin' to a shorter command.
 
 Supported VCS systems: %s""" % ", ".join(vcs.getNames())
-    usage = "prepare [path to directory or ChangeLog file]"
+    usage = "[path to directory or ChangeLog file]"
     aliases = ["pr", "prep", ]
 
     def getCTags(self):
@@ -571,7 +579,10 @@ Supported VCS systems: %s""" % ", ".join(vcs.getNames())
 
                 if binary:
                     self.stdout.write('Extracting affected tags from source.\n')
-                    command = "%s -u --fields=+nlS -f - %s" % (
+                    # -q includes extra class-qualified tag entry for each tag
+                    # which is a member of a class;
+                    # see https://thomas.apestaart.org/moap/trac/ticket/283
+                    command = "%s -u --fields=+nlS --extra=+q -f - %s" % (
                         binary, " ".join(ctagsFiles))
                     self.debug('Running command %s' % command)
                     output = commands.getoutput(command)
@@ -643,13 +654,11 @@ Supported VCS systems: %s""" % ", ".join(vcs.getNames())
         if added:
             self.debug('Handling path additions')
             for path in added:
-                path = filePathRelative(vcsPath, path)
                 writeLine("%s (added)" % path)
 
         if deleted:
             self.debug('Handling path deletions')
             for path in deleted:
-                path = filePathRelative(vcsPath, path)
                 writeLine("%s (deleted)" % path)
 
         os.write(fd, "\n")
@@ -676,8 +685,6 @@ class ChangeLog(util.LogCommand):
     ivar clPath: path to the ChangeLog file, for subcommands to use.
     type clPath: str
     """
-    usage = "changelog %command"
-
     summary = "act on ChangeLog file"
     description = """Act on a ChangeLog file.
 
