@@ -34,13 +34,20 @@ class Freshmeat(util.LogCommand):
     description = """This command submits a release to Freshmeat.
 Login details are taken from $HOME/.netrc.  Add a section for a machine named
 "freshmeat" with login and password settings.
+
+Use --name if you want to override the project's name gotten from the .DOAP
+file; to be used for example if your project uses dashes in the name which
+Freshmeat does not allow.
 """
 
     def addOptions(self):
         self.parser.add_option('-b', '--branch',
             action="store", dest="branch",
             help="branch to submit, overriding the doap branch")
- 
+        self.parser.add_option('-n', '--name',
+            action="store", dest="name",
+            help="name to submit, overriding the project name")
+  
     def handleOptions(self, options):
         self.options = options
 
@@ -76,10 +83,12 @@ Login details are taken from $HOME/.netrc.  Add a section for a machine named
 
         # branches on Freshmeat are called "Default" by default
         branch = self.options.branch or release.version.branch or "Default"
+        name = self.options.name or project.shortname
+        
         # submit
         # FIXME: how do we get changes and release_focus ?
         args = {
-            'project_name':        project.shortname,
+            'project_name':        name,
             'branch_name':         branch,
             'version':             release.version.revision,
             'changes':             "Unknown",
@@ -256,7 +265,7 @@ END:VEVENT
 
 class Mail(util.LogCommand):
     summary = "send release announcement through mail"
-    usage = "mail [mail-options] [TO]..."
+    usage = "[mail-options] [TO]..."
     description = """Send out release announcement mail.
 The To: addresses can be specified as arguments to the mail command."""
 
@@ -452,7 +461,7 @@ class Doap(util.LogCommand):
     @ivar doap: the L{doap.Doap} object.
     """
 
-    usage = "doap [doap-options] %command"
+    usage = "[doap-options] %command"
     description = "read and act on DOAP file"
     subCommandClasses = [Freshmeat, Ical, Mail, Rss, Search, Show, bug.Bug]
 
