@@ -56,24 +56,53 @@ COLORS = {ERROR: 'RED',
           WARN: 'YELLOW',
           INFO: 'GREEN',
           DEBUG: 'BLUE',
-          LOG: 'CYAN'
-          }
+          LOG: 'CYAN'}
 
 _FORMATTED_LEVELS = []
+_LEVEL_NAMES = ['ERROR', 'WARN', 'INFO', 'DEBUG', 'LOG']
+
 
 def getLevelName(level):
     """
     Return the name of a log level.
+    @param level: The level we want to know the name
+    @type level: int
+    @return: The name of the level
+    @rtype: str
     """
     assert isinstance(level, int) and level > 0 and level < 6, \
-           "Bad debug level"
-    return ('ERROR', 'WARN', 'INFO', 'DEBUG', 'LOG')[level - 1]
+           TypeError("Bad debug level")
+    return getLevelNames()[level - 1]
+
+
+def getLevelNames():
+    """
+    Return a list with the level names
+    @return: A list with the level names
+    @rtype: list of str
+    """
+    return _LEVEL_NAMES
+
+
+def getLevelInt(levelName):
+    """
+    Return the integer value of the levelName.
+    @param levelName: The string value of the level name
+    @type levelName: str
+    @return: The value of the level name we are interested in.
+    @rtype: int
+    """
+    assert isinstance(levelName, str) and levelName in getLevelNames(), \
+        "Bad debug level name"
+    return  getLevelNames().index(levelName)+1
+
 
 def getFormattedLevelName(level):
     assert isinstance(level, int) and level > 0 and level < 6, \
-           "Bad debug level"
+           TypeError("Bad debug level")
     return _FORMATTED_LEVELS[level - 1]
 
+
 def registerCategory(category):
     """
     Register a given category in the debug system.
@@ -98,7 +127,7 @@ def registerCategory(category):
 
         # our glob is unix filename style globbing, so cheat with fnmatch
         # fnmatch.fnmatch didn't work for this, so don't use it
-        if category in fnmatch.filter((category,), spec):
+        if category in fnmatch.filter((category, ), spec):
             # we have a match, so set level based on string or int
             if not value:
                 continue
@@ -109,6 +138,7 @@ def registerCategory(category):
     # store it
     _categories[category] = level
 
+
 def getCategoryLevel(category):
     """
     @param category: string
@@ -117,10 +147,11 @@ def getCategoryLevel(category):
     if it wasn't registered yet.
     """
     global _categories
-    if not _categories.has_key(category):
+    if not category in _categories:
         registerCategory(category)
     return _categories[category]
 
+
 def setLogSettings(state):
     """Update the current log settings.
     This can restore an old saved log settings object returned by
@@ -133,13 +164,14 @@ def setLogSettings(state):
     global _log_handlers_limited
 
     (_DEBUG,
-     _categories,
+     categories,
      _log_handlers,
      _log_handlers_limited) = state
 
-    for category in _categories:
+    for category in categories:
         registerCategory(category)
 
+
 def getLogSettings():
     """Fetches the current log settings.
     The returned object can be sent to setLogSettings to restore the
@@ -151,6 +183,7 @@ def getLogSettings():
             _log_handlers,
             _log_handlers_limited)
 
+
 def _canShortcutLogging(category, level):
     if _log_handlers:
         # we have some loggers operating without filters, have to do
@@ -159,6 +192,7 @@ def _canShortcutLogging(category, level):
     else:
         return level > getCategoryLevel(category)
 
+
 def scrubFilename(filename):
     '''
     Scrub the filename to a relative path for all packages in our scrub list.
@@ -171,6 +205,7 @@ def scrubFilename(filename):
 
     return filename
 
+
 def getFileLine(where=-1):
     """
     Return the filename and line number for the given location.
@@ -213,6 +248,7 @@ def getFileLine(where=-1):
 
     return scrubFilename(co.co_filename), lineno
 
+
 def ellipsize(o):
     """
     Ellipsize the representation of the given object.
@@ -224,6 +260,7 @@ def ellipsize(o):
     r = r[:60] + ' ... ' + r[-15:]
     return r
 
+
 def getFormatArgs(startFormat, startArgs, endFormat, endArgs, args, kwargs):
     """
     Helper function to create a format and args to use for logging.
@@ -236,12 +273,13 @@ def getFormatArgs(startFormat, startArgs, endFormat, endArgs, args, kwargs):
     for items in kwargs.items():
         debugArgs.extend(items)
     debugArgs.extend(endArgs)
-    format = startFormat \
-              + ', '.join(('%s',) * len(args)) \
+    debugFormat = startFormat \
+              + ', '.join(('%s', ) * len(args)) \
               + (kwargs and ', ' or '') \
-              + ', '.join(('%s=%r',) * len(kwargs)) \
+              + ', '.join(('%s=%r', ) * len(kwargs)) \
               + endFormat
-    return format, debugArgs
+    return debugFormat, debugArgs
+
 
 def doLog(level, object, category, format, args, where=-1,
     filePath=None, line=None):
@@ -279,26 +317,28 @@ def doLog(level, object, category, format, args, where=-1,
             try:
                 handler(level, object, category, file, line, message)
             except TypeError, e:
-                raise SystemError, "handler %r raised a TypeError: %s" % (
-                    handler, getExceptionMessage(e))
+                raise SystemError("handler %r raised a TypeError: %s" % (
+                    handler, getExceptionMessage(e)))
 
     if level > getCategoryLevel(category):
         return ret
 
-    for handler in _log_handlers_limited:
-        # set this a second time, just in case there weren't unlimited
-        # loggers there before
+    if _log_handlers_limited:
         if filePath is None and line is None:
             (filePath, line) = getFileLine(where=where)
         ret['filePath'] = filePath
         ret['line'] = line
-        try:
-            handler(level, object, category, filePath, line, message)
-        except TypeError:
-            raise SystemError, "handler %r raised a TypeError" % handler
+        for handler in _log_handlers_limited:
+            # set this a second time, just in case there weren't unlimited
+            # loggers there before
+            try:
+                handler(level, object, category, filePath, line, message)
+            except TypeError:
+                raise SystemError("handler %r raised a TypeError" % handler)
 
         return ret
 
+
 def errorObject(object, cat, format, *args):
     """
     Log a fatal error message in the given category.
@@ -314,6 +354,7 @@ def errorObject(object, cat, format, *args):
     else:
         raise SystemExit(format)
 
+
 def warningObject(object, cat, format, *args):
     """
     Log a warning message in the given category.
@@ -321,24 +362,28 @@ def warningObject(object, cat, format, *args):
     """
     doLog(WARN, object, cat, format, args)
 
+
 def infoObject(object, cat, format, *args):
     """
     Log an informational message in the given category.
     """
     doLog(INFO, object, cat, format, args)
 
+
 def debugObject(object, cat, format, *args):
     """
     Log a debug message in the given category.
     """
     doLog(DEBUG, object, cat, format, args)
 
+
 def logObject(object, cat, format, *args):
     """
     Log a log message.  Used for debugging recurring events.
     """
     doLog(LOG, object, cat, format, args)
 
+
 def safeprintf(file, format, *args):
     """Write to a file object, ignoring errors.
     """
@@ -354,6 +399,7 @@ def safeprintf(file, format, *args):
             os._exit(os.EX_OSERR)
         # otherwise ignore it, there's nothing you can do
 
+
 def stderrHandler(level, object, category, file, line, message):
     """
     A log handler that writes to stderr.
@@ -379,8 +425,8 @@ def stderrHandler(level, object, category, file, line, message):
 
     sys.stderr.flush()
 
+
 def _preformatLevels(noColorEnvVarName):
-    levels = ('ERROR', 'WARN', 'INFO', 'DEBUG', 'LOG')
     format = '%-5s'
 
     try:
@@ -397,9 +443,9 @@ def _preformatLevels(noColorEnvVarName):
 
         t = termcolor.TerminalController()
         formatter = lambda level: ''.join((t.BOLD, getattr(t, COLORS[level]),
-                            format % (levels[level-1],), t.NORMAL))
+                            format % (_LEVEL_NAMES[level-1], ), t.NORMAL))
     else:
-        formatter = lambda level: format % (levels[level-1],)
+        formatter = lambda level: format % (_LEVEL_NAMES[level-1], )
 
     for level in ERROR, WARN, INFO, DEBUG, LOG:
         _FORMATTED_LEVELS.append(formatter(level))
@@ -407,6 +453,8 @@ def _preformatLevels(noColorEnvVarName):
 ### "public" useful API
 
 # setup functions
+
+
 def init(envVarName, enableColorOutput=False):
     """
     Initialize the logging system and parse the environment variable
@@ -426,13 +474,14 @@ def init(envVarName, enableColorOutput=False):
     else:
         _preformatLevels(None)
 
-    if os.environ.has_key(envVarName):
+    if envVarName in os.environ:
         # install a log handler that uses the value of the environment var
         setDebug(os.environ[envVarName])
     addLimitedLogHandler(stderrHandler)
 
     _initialized = True
 
+
 def setDebug(string):
     """Set the DEBUG string.  This controls the log output."""
     global _DEBUG
@@ -446,6 +495,7 @@ def setDebug(string):
     for category in _categories:
         registerCategory(category)
 
+
 def getDebug():
     """
     Returns the currently active DEBUG string.
@@ -454,6 +504,7 @@ def getDebug():
     global _DEBUG
     return _DEBUG
 
+
 def setPackageScrubList(*packages):
     """
     Set the package names to scrub from filenames.
@@ -465,6 +516,7 @@ def setPackageScrubList(*packages):
     global _PACKAGE_SCRUB_LIST
     _PACKAGE_SCRUB_LIST = packages
 
+
 def reset():
     """
     Resets the logging system, removing all log handlers.
@@ -475,6 +527,7 @@ def reset():
     _log_handlers_limited = []
     _initialized = False
 
+
 def addLogHandler(func):
     """
     Add a custom log handler.
@@ -489,11 +542,12 @@ def addLogHandler(func):
     """
 
     if not callable(func):
-        raise TypeError, "func must be callable"
+        raise TypeError("func must be callable")
 
     if func not in _log_handlers:
         _log_handlers.append(func)
 
+
 def addLimitedLogHandler(func):
     """
     Add a custom log handler.
@@ -507,11 +561,12 @@ def addLimitedLogHandler(func):
     @raises TypeError: TypeError if func is not a callable
     """
     if not callable(func):
-        raise TypeError, "func must be callable"
+        raise TypeError("func must be callable")
 
     if func not in _log_handlers_limited:
         _log_handlers_limited.append(func)
 
+
 def removeLogHandler(func):
     """
     Remove a registered log handler.
@@ -542,22 +597,30 @@ def removeLimitedLogHandler(func):
     _log_handlers_limited.remove(func)
 
 # public log functions
+
+
 def error(cat, format, *args):
     errorObject(None, cat, format, *args)
 
+
 def warning(cat, format, *args):
     warningObject(None, cat, format, *args)
 
+
 def info(cat, format, *args):
     infoObject(None, cat, format, *args)
 
+
 def debug(cat, format, *args):
     debugObject(None, cat, format, *args)
 
+
 def log(cat, format, *args):
     logObject(None, cat, format, *args)
 
 # public utility functions
+
+
 def getExceptionMessage(exception, frame=-1, filename=None):
     """
     Return a short message based on an exception, useful for debugging.
@@ -578,6 +641,7 @@ def getExceptionMessage(exception, frame=-1, filename=None):
     return "exception %(exc)s at %(filename)s:%(line)s: %(func)s()%(msg)s" \
         % locals()
 
+
 def reopenOutputFiles():
     """
     Reopens the stdout and stderr output files, as set by
@@ -603,6 +667,7 @@ def reopenOutputFiles():
         reopen(_stderr, sys.stderr.fileno(), 0)
         debug('log', 'opened log %r', _stderr)
 
+
 def outputToFiles(stdout=None, stderr=None):
     """
     Redirect stdout and stderr to named files.
@@ -626,16 +691,23 @@ def outputToFiles(stdout=None, stderr=None):
             info('log', "Calling old SIGHUP hander")
             _old_hup_handler(signum, frame)
 
-    debug('log', 'installing SIGHUP handler')
-    import signal
-    handler = signal.signal(signal.SIGHUP, sighup)
-    if handler == signal.SIG_DFL or handler == signal.SIG_IGN:
-        _old_hup_handler = None
+    try:
+        import signal
+    except ImportError:
+        debug('log', 'POSIX signals not supported, unable to install'
+              ' SIGHUP handler')
     else:
-        _old_hup_handler = handler
+        debug('log', 'installing SIGHUP handler')
+        handler = signal.signal(signal.SIGHUP, sighup)
+        if handler == signal.SIG_DFL or handler == signal.SIG_IGN:
+            _old_hup_handler = None
+        else:
+            _old_hup_handler = handler
 
 
 # base class for loggable objects
+
+
 class Loggable:
     """
     Base class for objects that want to be able to log messages with
@@ -648,6 +720,22 @@ class Loggable:
 
     logCategory = 'default'
 
+    def writeMarker(self, marker, level):
+        """
+        Sets a marker that written to the logs. Setting this
+        marker to multiple elements at a time helps debugging.
+        @param marker: A string write to the log.
+        @type marker: str
+        @param level: The log level. It can be log.WARN, log.INFO,
+        log.DEBUG, log.ERROR or log.LOG.
+        @type  level: int
+        """
+        # errorObject specifically raises, so treat it specially
+        if level == ERROR:
+            self.error('%s', marker)
+
+        doLog(level, self.logObjectName(), self.logCategory, '%s', marker)
+
     def error(self, *args):
         """Log an error.  By default this will also raise an exception."""
         if _canShortcutLogging(self.logCategory, ERROR):
@@ -745,6 +833,7 @@ _initializedTwisted = False
 # make a singleton
 __theTwistedLogObserver = None
 
+
 def _getTheTwistedLogObserver():
     # used internally and in test
     global __theTwistedLogObserver
@@ -756,6 +845,8 @@ def _getTheTwistedLogObserver():
 
 
 # public helper methods
+
+
 def getFailureMessage(failure):
     """
     Return a short message based on L{twisted.python.failure.Failure}.
@@ -771,6 +862,7 @@ def getFailureMessage(failure):
     return "failure %(exc)s at %(filename)s:%(line)s: %(func)s(): %(msg)s" \
         % locals()
 
+
 def warningFailure(failure, swallow=True):
     """
     Log a warning about a Failure. Useful as an errback handler:
@@ -783,6 +875,7 @@ def warningFailure(failure, swallow=True):
     if not swallow:
         return failure
 
+
 def logTwisted():
     """
     Integrate twisted's logger with our logger.
@@ -808,7 +901,7 @@ def logTwisted():
     # we don't want logs for pb.Error types since they
     # are specifically raised to be handled on the other side
     observer = _getTheTwistedLogObserver()
-    observer.ignoreErrors([pb.Error,])
+    observer.ignoreErrors([pb.Error, ])
     tlog.startLoggingWithObserver(observer.emit, False)
 
     _initializedTwisted = True
@@ -816,6 +909,8 @@ def logTwisted():
 
 # we need an object as the observer because startLoggingWithObserver
 # expects a bound method
+
+
 class TwistedLogObserver(Loggable):
     """
     Twisted log observer that integrates with our logging.
@@ -829,12 +924,13 @@ class TwistedLogObserver(Loggable):
         method = log # by default, lowest level
         edm = eventDict['message']
         if not edm:
-            if eventDict['isError'] and eventDict.has_key('failure'):
+            if eventDict['isError'] and 'failure' in eventDict:
                 f = eventDict['failure']
                 for failureType in self._ignoreErrors:
                     r = f.check(failureType)
                     if r:
-                        self.debug("Failure of type %r, ignoring" % failureType)
+                        self.debug("Failure of type %r, ignoring" %
+                                   failureType)
                         return
 
                 self.log("Failure %r" % f)
@@ -848,7 +944,7 @@ class TwistedLogObserver(Loggable):
                 text = f.getTraceback()
                 safeprintf(sys.stderr, "\nTwisted traceback:\n")
                 safeprintf(sys.stderr, text + '\n')
-            elif eventDict.has_key('format'):
+            elif 'format' in eventDict:
                 text = eventDict['format'] % eventDict
             else:
                 # we don't know how to log this
@@ -856,10 +952,9 @@ class TwistedLogObserver(Loggable):
         else:
             text = ' '.join(map(str, edm))
 
-        fmtDict = { 'system': eventDict['system'],
-                    'text': text.replace("\n", "\n\t")
-                  }
-        msgStr = " [%(system)s] %(text)s\n" % fmtDict
+        msgStr = " [%(system)s] %(text)s\n" % {
+                'system': eventDict['system'],
+                'text': text.replace("\n", "\n\t")}
         # because msgstr can contain %, as in a backtrace, make sure we
         # don't try to splice it
         method('twisted', msgStr)
