@@ -3,7 +3,7 @@
 
 import sys
 
-from moap.command import doap, cl, ignore, bug, code, tracadmin
+from moap.command import doap, cl, ignore, bug, code, tracadmin, vcs
 
 from moap.util import log, util, deps
 
@@ -31,7 +31,7 @@ You can get help on subcommands by using the -h option to the subcommand.
 """
 
     subCommandClasses = [doap.Doap, cl.ChangeLog, ignore.Ignore, bug.Bug,
-        code.Code, tracadmin.TracAdmin]
+        code.Code, tracadmin.TracAdmin, vcs.VCS]
 
     def addOptions(self):
         # FIXME: is this the right place ?
