@@ -3,11 +3,11 @@
 
 import os
 
-from common import unittest
-
 from moap.bug import bugzilla
 
-class TestGstCsv(unittest.TestCase):
+from moap.test import common
+
+class TestGstCsv(common.TestCase):
     def setUp(self):
         file = os.path.join(os.path.dirname(__file__), 'bugzilla',
             'gst-plugins-base-0.10.2.csv')
@@ -21,7 +21,7 @@ class TestGstCsv(unittest.TestCase):
                 return
         self.fail('Did not find bug 324696')
 
-class TestRDFGst:#(unittest.TestCase):
+class TestRDFGst:#(common.TestCase):
     try:
         import RDF
     except ImportError:
