@@ -3,11 +3,11 @@
 
 import os
 
-from common import unittest
-
 from moap.doap import doap
 
-class TestDoap(unittest.TestCase):
+from moap.test import common
+
+class TestDoap(common.TestCase):
     def setUp(self):
         file = os.path.join(os.path.dirname(__file__), 'doap', 'mach.doap')
         self.doap = doap.Doap()
