@@ -3,15 +3,15 @@
 
 import os
 
-from common import unittest
-
 from moap.util import distro
 
-class TestRelease(unittest.TestCase):
+from moap.test import common
+
+class TestRelease(common.TestCase):
     def testGet(self):
         distro.getDistroFromRelease()
 
-class TestAtLeast(unittest.TestCase):
+class TestAtLeast(common.TestCase):
     def testFedora(self):
         d = distro.Distro('fedora', 'Fedora Core', '5', 'i386')
         self.failUnless(d.atLeast('4test2'))
