@@ -4,11 +4,11 @@
 import os
 import tempfile
 
-from common import unittest
-
 from moap.util import usermap
 
-class TestUserMap(unittest.TestCase):
+from moap.test import common
+
+class TestUserMap(common.TestCase):
     def setUp(self):
         self.map = usermap.UserMap()
 
