@@ -29,14 +29,14 @@ def detect(path):
 class GitSvn(git.Git):
     name = 'git-svn'
 
-    def getNotIgnored(self):
-        return git.Git.getNotIgnored(self)
+    def getUnknown(self, path):
+        return git.Git.getUnknown(self, path)
     
     def update(self, path):
         oldPath = os.getcwd()
         os.chdir(self.path)
 
-        status, output = commands.getstatusoutput("git-svn fetch")
+        status, output = commands.getstatusoutput("git svn fetch")
         if status != 0:
             raise vcs.VCSException(output)
 
@@ -44,7 +44,7 @@ class GitSvn(git.Git):
         if status != 0:
             raise vcs.VCSException(output)
 
-        status, output = commands.getstatusoutput("git-svn show-ignore >> .git/info/exclude")
+        status, output = commands.getstatusoutput("git svn show-ignore >> .git/info/exclude")
         if status != 0:
             raise vcs.VCSException(output)
 
